pub fn parse_program_spanned_with_depth(
src: &str,
max_depth: usize,
) -> Result<Vec<(Sexp, Span)>, ParseError>Expand description
parse_program_spanned with the nesting bound supplied by the caller.
pub fn parse_program_spanned_with_depth(
src: &str,
max_depth: usize,
) -> Result<Vec<(Sexp, Span)>, ParseError>parse_program_spanned with the nesting bound supplied by the caller.